@@ -93,8 +93,7 @@ class CredentialsPrompt:
     This implementation prompts the user in a terminal using standard in/out.
     """
 
-    @staticmethod
-    def get_email():
+    def get_email(self):  # pylint: disable=no-self-use
         """Prompt for email.
 
         Returns:
@@ -103,8 +102,7 @@ class CredentialsPrompt:
         print('Sign in with your Google account:')
         return input('Email: ')
 
-    @staticmethod
-    def get_password():
+    def get_password(self):  # pylint: disable=no-self-use
         """Prompt for password.
 
         Returns:
@@ -112,8 +110,7 @@ class CredentialsPrompt:
         """
         return getpass.getpass()
 
-    @staticmethod
-    def get_verification_code():
+    def get_verification_code(self):  # pylint: disable=no-self-use
         """Prompt for verification code.
 
         Returns:
@@ -121,8 +118,7 @@ class CredentialsPrompt:
         """
         return input('Verification code: ')
 
-    @staticmethod
-    def get_authorization_code():
+    def get_authorization_code(self):  # pylint: disable=no-self-use
         """Prompt for authorization code.
 
         Returns:
@@ -332,9 +328,9 @@ def _get_authorization_code(session, credentials_prompt):
             input_selector = PHONE_CODE_SELECTOR
         else:
             raise GoogleAuthError('Unknown verification code input')
-        verfification_code = credentials_prompt.get_verification_code()
+        verification_code = credentials_prompt.get_verification_code()
         browser.submit_form(
-            VERIFICATION_FORM_SELECTOR, {input_selector: verfification_code}
+            VERIFICATION_FORM_SELECTOR, {input_selector: verification_code}
         )
 
     try:
